# Cli tool for managing enabledu plugins

# Usage

```bash
 $ appins --help
   Usage: appins [OPTIONS] COMMAND [ARGS]...
   
   Commands:
      get-app     Clone a repository from GitHub into apps directory.
      init        Create a new project from a template.
      remove-app  Remove an app from the apps directory.
      start       Start the FastAPI server.
 ```
